@@ -1,20 +1,22 @@
+## File Name: summary.lsem.permutationTest.R
+## File Version: 0.17
+## File Last Change: 2017-09-20 10:53:40
 ######################################################
 summary.lsem.permutationTest <- function( object , file=NULL , digits=3 , ... ){
 
 	# open sink for a file
-	CDM::osink( file=file , suffix="__SUMMARY.Rout" )
+	sirt_osink( file=file )
 
 	cat("-----------------------------------------------------------------\n")
 	cat("Permutation Test for Local Structural Equation Model \n\n")
-		
-	cat( package_version_date("sirt") , "\n" )
-	cat( package_version_date("lavaan") , "\n" )	
-	cat( package_version_date("lavaan.survey") , "\n" )					
+				
+	packages <- c("sirt", "lavaan", "lavaan.survey")
+	sirt_summary_print_packages(packages=packages)	
 	
 	cat("\nFunction 'sirt::lsem.permutationTest' \n\n")
 	
-	cat("Call:\n", paste(deparse(object$CALL), sep = "\n", collapse = "\n"), 
-				"\n\n", sep = "")	
+	#- print call
+	sirt_summary_print_call(CALL=object$CALL)
 	
 	cat( "Date of Analysis:" , paste( object$s2 ) , "\n" )
 	cat("Computation Time:" , print(object$s2 - object$s1), "\n\n")
@@ -50,7 +52,7 @@ summary.lsem.permutationTest <- function( object , file=NULL , digits=3 , ... ){
 	print(obji)	
 
 	# close file
-	CDM::csink(file)
+	sirt_csink(file=file)
 	
 }
 ######################################################			
